'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var fetch = _interopDefault(require('unfetch'));
var GAFormFields = _interopDefault(require('@hashicorp/hashi-ga-form-fields'));
var PrivacyCheckbox = _interopDefault(require('@hashicorp/hashi-privacy-checkbox'));

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function CheckCircle(props) {
  return preact.h(
    "svg",
    _extends({ xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 24 24", fill: "none", stroke: "#fff", strokeWidth: 2, strokeLinecap: "round", strokeLinejoin: "round", className: "feather feather-check-circle", width: 24, height: 24 }, props),
    preact.h(
      "title",
      null,
      "Checkmark"
    ),
    preact.h("path", { d: "M22 11.07V12a10 10 0 1 1-5.93-9.14" }),
    preact.h("path", { d: "M23 3L12 14l-3-3" })
  );
}

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
var cookie = require('js-cookie');

var NewsletterSignupForm = function (_Component) {
  _inherits(NewsletterSignupForm, _Component);

  function NewsletterSignupForm(props) {
    _classCallCheck(this, NewsletterSignupForm);

    var _this = _possibleConstructorReturn(this, (NewsletterSignupForm.__proto__ || Object.getPrototypeOf(NewsletterSignupForm)).call(this, props));

    _this.action = 'https://util.hashicorp.com/forms/standard';
    _this.submit = _this.submit.bind(_this);
    _this.onEmailValueChange = _this.onEmailValueChange.bind(_this);
    _this.state = {
      subClass: null,
      disabled: false,
      emailValue: null,
      forceValidate: false,
      privacyValid: false
    };
    return _this;
  }

  _createClass(NewsletterSignupForm, [{
    key: 'onEmailValueChange',
    value: function onEmailValueChange(e) {
      var value = e.target.value;
      this.setState({ emailValue: value });

      // save for future use in other forms
      window.localStorage.setItem('prevVal_emailValue', value);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      require('promise-polyfill').default;
      require('@hashicorp/localstorage-polyfill/dist');

      var prevVal = window.localStorage.getItem('prevVal_emailValue');
      if (prevVal !== null) {
        this.setState({ emailValue: prevVal });
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var classes = ['g-newsletter-signup-form'];
      if (this.state.subClass) {
        classes.push(this.state.subClass);
      }
      if (this.props.on_dark) {
        classes.push('on-dark');
      }

      return preact.h(
        'form',
        {
          onSubmit: this.submit,
          'class': classes.join(' '),
          'data-state': this.props._state,
          'data-form-type': 'newsletter-signup',
          'data-placement': this.props.placement
        },
        preact.h(GAFormFields, null),
        preact.h(
          'div',
          { 'class': 'row-1' },
          preact.h('input', {
            'class': 'g-input email',
            type: 'email',
            name: 'email',
            placeholder: this.props.placeholder || 'Email address',
            required: true,
            disabled: this.state.disabled,
            value: this.state.emailValue,
            onChange: this.onEmailValueChange
          }),
          preact.h('input', {
            'class': 'g-btn',
            type: 'submit',
            value: this.props.button_text || 'Subscribe to Newsletter',
            disabled: this.state.disabled
          })
        ),
        preact.h(
          'div',
          { 'class': 'row-2' },
          preact.h(PrivacyCheckbox, {
            on_dark: this.props.on_dark,
            forceValidate: this.state.forceValidate,
            onValidityChange: function onValidityChange(s) {
              return _this2.setState({ privacyValid: s });
            }
          })
        ),
        preact.h(
          'div',
          { 'class': 'success-content' },
          preact.h(CheckCircle, null),
          preact.h(
            'h4',
            null,
            'Thanks for subscribing!'
          )
        )
      );
    }

    // for a single field without validation, a controlled form isn't necessary

  }, {
    key: 'submit',
    value: function submit(e) {
      var _this3 = this;

      e.preventDefault();
      var requestBody = {};

      // validate privacy policy checked
      if (!this.state.privacyValid) {
        this.setState({ forceValidate: true });
        return false;
      }

      // add utm fields
      var utmFields = this.base.querySelectorAll('.g-ga-form-fields input');
      for (var i = 0; i < utmFields.length; i++) {
        var el = utmFields[i];
        // correct for legacy salesforce values
        if (el.attributes.name.value === 'campaignID__c') {
          requestBody['ga_campaign_id'] = el.value;
        } else if (el.attributes.name.value === 'Google_Analytics_Client_ID__c') {
          requestBody['ga_client_id'] = el.value;
        } else {
          requestBody[el.attributes.name.value.replace(/__c$/, '')] = el.value;
        }
      }
      // add email field
      requestBody.email = this.state.emailValue;
      // Add emailSignup, which will trigger the Marketo
      // event to sign the user up for the newsletter
      requestBody.emailSignup = true;
      // Adds Munchkin Cookie
      requestBody.munchkinCookie = cookie.get('_mkto_trk');
      // disable button
      this.setState({ disabled: true, subscribeStatus: 'Submitting...' });

      // ship it
      fetch(this.action, {
        method: 'POST',
        body: JSON.stringify(requestBody),
        headers: {
          Accept: 'application/json',
          'Content-Type': 'application/json'
        }
      }).then(function (res) {
        if (!res.ok) throw Error(res.statusText);
        return res;
      }).then(function (res) {
        return res.json();
      }).then(function () {
        _this3.setState({ subClass: 'success' }, function () {
          // Call the finished function to notify a parent element that form is done
          _this3.props.finished && _this3.props.finished({ error: null });
        });
      }).catch(function (err) {
        _this3.setState({ subscribeStatus: 'An error occurred', subClass: 'err' }, function () {
          // Call the finished function to notify a parent element that form is done.
          // Call it on error as well so that any further action isn't held up, but include
          // the err value so the parent can choose what to do with it.
          _this3.props.finished && _this3.props.finished({ error: err });
        });
        console.log(err); /* eslint-disable-line no-console */
      });
    }
  }]);

  return NewsletterSignupForm;
}(preact.Component);

module.exports = NewsletterSignupForm;
